import json

__virtualname__ = "json"


def _default(data):
    if isinstance(data, set):
        return sorted(data)
    elif hasattr(data, "__iter__"):
        return list(data)
    else:
        return repr(data)


def dump(hub, data) -> bytes:
    return json.dumps(data, default=_default, allow_nan=True, cls=None).encode()


def load(hub, data: bytes):
    return json.loads(data.decode())



"""
Serialize data by casting it to a plain string
"""
import ast

__virtualname__ = "str"


def dump(hub, data) -> bytes:
    return str(data).encode()


def load(hub, data: bytes):
    data = data.decode()
    try:
        return ast.literal_eval(data)
    except:
        return data



import msgpack

__virtualname__ = "msgpack"


def _default(data):
    if isinstance(data, set):
        return sorted(data)
    elif hasattr(data, "__iter__"):
        return list(data)
    else:
        return repr(data)


def dump(hub, data) -> bytes:
    return msgpack.packb(data, datetime=True, default=_default)


def load(hub, data: bytes):
    return msgpack.unpackb(data, strict_map_key=False)
